==> VulkanMemoryAllocator-v3.2.1.tar.lz: VulkanMemoryAllocator-v3.2.1/docs/html/search/all_2.js <==
var searchData=
[
  ['cache_20flush_20and_20invalidate_0',['Cache flush and invalidate',['../memory_mapping.html#memory_mapping_cache_control',1,'']]],
  ['callbacks_1',['Device memory allocation callbacks',['../configuration.html#allocation_callbacks',1,'']]],
  ['cases_2',['Other use cases',['../usage_patterns.html#usage_patterns_other_use_cases',1,'']]],
  ['choosing_20memory_20type_3',['Choosing memory type',['../choosing_memory_type.html',1,'index']]],
  ['choosing_20memory_20type_20index_4',['Choosing memory type index',['../custom_memory_pools.html#custom_memory_pools_MemTypeIndex',1,'']]],
  ['compatibility_5',['Versioning and compatibility',['../general_considerations.html#general_considerations_versioning_and_compatibility',1,'']]],
  ['configuration_6',['Configuration',['../configuration.html',1,'index']]],
  ['configuration_20options_7',['Other configuration options',['../quick_start.html#quick_start_initialization_other_config',1,'']]],
  ['considerations_8',['considerations',['../virtual_allocator.html#virtual_allocator_additional_considerations',1,'Additional considerations'],['../general_considerations.html',1,'General considerations']]],
  ['controlling_20memory_20usage_9',['Controlling memory usage',['../staying_within_budget.html#staying_within_budget_controlling_memory_usage',1,'']]],
  ['copy_20for_20upload_10',['Staging copy for upload',['../usage_patterns.html#usage_patterns_staging_copy_upload',1,'']]],
  ['copy_20functions_11',['Copy functions',['../memory_mapping.html#memory_mapping_copy_functions',1,'']]],
  ['corruption_20detection_12',['Corruption detection',['../debugging_memory_usage.html#debugging_memory_usage_corruption_detection',1,'']]],
  ['creating_20virtual_20block_13',['Creating virtual block',['../virtual_allocator.html#virtual_allocator_creating_virtual_block',1,'']]],
  ['custom_20alignment_14',['Custom alignment',['../other_api_interop.html#opengl_interop_custom_alignment',1,'']]],
  ['custom_20host_20memory_20allocator_15',['Custom host memory allocator',['../configuration.html#custom_memory_allocator',1,'']]],
  ['custom_20memory_20pools_16',['Custom memory pools',['../custom_memory_pools.html',1,'Custom memory pools'],['../choosing_memory_type.html#choosing_memory_type_custom_memory_pools',1,'Custom memory pools']]],
  ['custom_20pools_17',['When not to use custom pools',['../custom_memory_pools.html#custom_memory_pools_when_not_use',1,'']]]
];

==> VulkanMemoryAllocator-v3.3.0.tar.lz: VulkanMemoryAllocator-v3.3.0/docs/html/search/all_2.js <==
var searchData=
[
  ['cache_20flush_20and_20invalidate_0',['Cache flush and invalidate',['../memory_mapping.html#memory_mapping_cache_control',1,'']]],
  ['callbacks_1',['Device memory allocation callbacks',['../configuration.html#allocation_callbacks',1,'']]],
  ['cases_2',['Other use cases',['../usage_patterns.html#usage_patterns_other_use_cases',1,'']]],
  ['choosing_20memory_20type_3',['Choosing memory type',['../choosing_memory_type.html',1,'faq']]],
  ['choosing_20memory_20type_20index_4',['Choosing memory type index',['../custom_memory_pools.html#custom_memory_pools_MemTypeIndex',1,'']]],
  ['compatibility_5',['Versioning and compatibility',['../general_considerations.html#general_considerations_versioning_and_compatibility',1,'']]],
  ['configuration_6',['Configuration',['../configuration.html',1,'index']]],
  ['configuration_20options_7',['Other configuration options',['../quick_start.html#quick_start_initialization_other_config',1,'']]],
  ['considerations_8',['considerations',['../virtual_allocator.html#virtual_allocator_additional_considerations',1,'Additional considerations'],['../general_considerations.html',1,'General considerations']]],
  ['controlling_20memory_20usage_9',['Controlling memory usage',['../staying_within_budget.html#staying_within_budget_controlling_memory_usage',1,'']]],
  ['copy_20for_20upload_10',['Staging copy for upload',['../usage_patterns.html#usage_patterns_staging_copy_upload',1,'']]],
  ['copy_20functions_11',['Copy functions',['../memory_mapping.html#memory_mapping_copy_functions',1,'']]],
  ['corruption_20detection_12',['Corruption detection',['../debugging_memory_usage.html#debugging_memory_usage_corruption_detection',1,'']]],
  ['creating_20virtual_20block_13',['Creating virtual block',['../virtual_allocator.html#virtual_allocator_creating_virtual_block',1,'']]],
  ['custom_20alignment_14',['Custom alignment',['../other_api_interop.html#opengl_interop_custom_alignment',1,'']]],
  ['custom_20host_20memory_20allocator_15',['Custom host memory allocator',['../configuration.html#custom_memory_allocator',1,'']]],
  ['custom_20memory_20pools_16',['Custom memory pools',['../custom_memory_pools.html',1,'Custom memory pools'],['../choosing_memory_type.html#choosing_memory_type_custom_memory_pools',1,'Custom memory pools']]],
  ['custom_20pools_17',['When not to use custom pools',['../custom_memory_pools.html#custom_memory_pools_when_not_use',1,'']]]
];
